@@ -52,8 +52,16 @@ def register_message_consumer(config_class):
             accept=config.accept,
             **consumer_direct_params
         )
+
+    elif config.consumer_type == 'fanout':
+        consumer_thread = MessageConsumer(
+            exchange_name=config.exchange_name,
+            accept=config.accept,
+            **consumer_direct_params
+        )
+
     else:
-        raise ValueError('consumer_type must be direct or topic.')
+        raise ValueError("consumer_type must be either 'direct' or 'topic' or 'fanout'")
 
     def callback(obj, payload, headers, properties):
         '''obj will be occupied by self'''
